# Changelog
## 0.3.2 (2025-01-29)

### Fix

- **dep**: upgrade plotly to 6.0.0

## 0.3.1 (2025-01-28)

### Fix

- catch the case that both pelican_conf and metadata path are not provided

## 0.3.0 (2021-01-24)

### Feat

- **plot**: enable loading from collected article metadata

## 0.2.0 (2021-01-21)

### Refactor

- use stderr to replace exception
- **collector**: add extract_articles_info

### Feat

- **plotter**: implement trend_plot

## 0.1.0 (2021-01-20)

### Feat

- **main**: implement collect command
- **collector**: collect article info from pelican project
- initialize project

### Fix

- **github-action**: fix python-check typo
